==> tripwire_2.4.3.1.orig.tar.gz: tripwire-open-source-2.4.3.1/src/fs/fsnametranslator.h <==
//
// The developer of the original code and/or files is Tripwire, Inc.
// Portions created by Tripwire, Inc. are copyright (C) 2000 Tripwire,
// Inc. Tripwire is a registered trademark of Tripwire, Inc.  All rights
// reserved.
// 
// This program is free software.  The contents of this file are subject
// to the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2 of the License, or (at your
// option) any later version.  You may redistribute it and/or modify it
// only in compliance with the GNU General Public License.
// 
// This program is distributed in the hope that it will be useful.
// However, this program is distributed AS-IS WITHOUT ANY
// WARRANTY; INCLUDING THE IMPLIED WARRANTY OF MERCHANTABILITY OR FITNESS
// FOR A PARTICULAR PURPOSE.  Please see the GNU General Public License
// for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
// 
// Nothing in the GNU General Public License or any other license to use
// the code or files shall permit you to use Tripwire's trademarks,
// service marks, or other intellectual property without Tripwire's
// prior written consent.
// 
// If you have any questions, please contact Tripwire, Inc. at either
// info@tripwire.org or www.tripwire.org.
//
///////////////////////////////////////////////////////////////////////////////
// fsnametranslator.h
//

#ifndef __FSNAMETRANSLATOR_H
#define __FSNAMETRANSLATOR_H

//=========================================================================
// INCLUDES
//=========================================================================

#ifndef __FCONAMETRANSLATOR_H
#include "fco/fconametranslator.h"
#endif

//=========================================================================
// DECLARATION OF CLASSES
//=========================================================================

class cFSNameTranslator : public iFCONameTranslator
{
public:
    //
    // basic functionality
    //    
    virtual TSTRING ToStringRaw( const cFCOName& name ) const;
    virtual TSTRING ToStringAPI( const cFCOName& name ) const;
    virtual TSTRING ToStringDisplay( const cFCOName& name, bool bUnique = false ) const;
    virtual bool DisplayStringToFCOName( const TSTRING& str, cFCOName& name ) const;
    
    virtual ~cFSNameTranslator() {}
};

#endif //__FSNAMETRANSLATOR_H

==> tripwire_2.4.3.7.orig.tar.gz: tripwire-open-source-2.4.3.7/src/fs/fsnametranslator.h <==
//
// The developer of the original code and/or files is Tripwire, Inc.
// Portions created by Tripwire, Inc. are copyright (C) 2000-2018 Tripwire,
// Inc. Tripwire is a registered trademark of Tripwire, Inc.  All rights
// reserved.
//
// This program is free software.  The contents of this file are subject
// to the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2 of the License, or (at your
// option) any later version.  You may redistribute it and/or modify it
// only in compliance with the GNU General Public License.
//
// This program is distributed in the hope that it will be useful.
// However, this program is distributed AS-IS WITHOUT ANY
// WARRANTY; INCLUDING THE IMPLIED WARRANTY OF MERCHANTABILITY OR FITNESS
// FOR A PARTICULAR PURPOSE.  Please see the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
//
// Nothing in the GNU General Public License or any other license to use
// the code or files shall permit you to use Tripwire's trademarks,
// service marks, or other intellectual property without Tripwire's
// prior written consent.
//
// If you have any questions, please contact Tripwire, Inc. at either
// info@tripwire.org or www.tripwire.org.
//
///////////////////////////////////////////////////////////////////////////////
// fsnametranslator.h
//

#ifndef __FSNAMETRANSLATOR_H
#define __FSNAMETRANSLATOR_H

//=========================================================================
// INCLUDES
//=========================================================================

#ifndef __FCONAMETRANSLATOR_H
#include "fco/fconametranslator.h"
#endif

//=========================================================================
// DECLARATION OF CLASSES
//=========================================================================

class cFSNameTranslator : public iFCONameTranslator
{
public:
    //
    // basic functionality
    //
    virtual TSTRING ToStringRaw(const cFCOName& name) const;
    virtual TSTRING ToStringAPI(const cFCOName& name) const;
    virtual TSTRING ToStringDisplay(const cFCOName& name, bool bUnique = false) const;
    virtual bool    DisplayStringToFCOName(const TSTRING& str, cFCOName& name) const;

    virtual ~cFSNameTranslator()
    {
    }
};

#endif //__FSNAMETRANSLATOR_H
